!
! Copyright (C) 2013 A. Dal Corso 
! This file is distributed under the terms of the
! GNU General Public License. See the file `License'
! in the root directory of the present distribution,
! or http://www.gnu.org/copyleft/gpl.txt .
!
SUBROUTINE set_hamiltonian(xk,ecut,npw)
!
!  This routine sets the free electron Hamiltonian. 
!
USE kinds, ONLY   : dp
USE freemod, ONLY   : g, et, ngm, nbnd

IMPLICIT NONE

REAL(DP), INTENT(IN) :: xk(3), ecut
INTEGER, INTENT(OUT) :: npw

REAL(DP), ALLOCATABLE :: xkpg2(:)
INTEGER,  ALLOCATABLE :: igk(:)

ALLOCATE(xkpg2(ngm))
ALLOCATE(igk(ngm))
!
! ++++ Compute all k+G within a sphere of radius sqrt(ecut) 
!      call npw the number of plane waves and set their modulus in xkpg2
!

IF (npw < nbnd) THEN
   write(6,*) "Too few plane waves, increase cut-off"
   stop 1
ENDIF 
!
!   Order the k+G vectors 
!
CALL hpsort(npw, xkpg2, igk )
!
! ++++ The matrix is already diagonal, so take the lowest nbnd eigenvalues
!

DEALLOCATE(xkpg2)
DEALLOCATE(igk)

RETURN
END SUBROUTINE set_hamiltonian

